@@ -11,7 +11,7 @@ use POSIX qw( strftime );
 use Moo;
 with "Archive::BagIt::Role::Portability";
 
-our $VERSION = '0.087'; # VERSION
+our $VERSION = '0.088'; # VERSION
 
 # ABSTRACT: The main module to handle bags.
 
@@ -30,7 +30,10 @@ around 'BUILDARGS' , sub {
 
 sub BUILD {
     my ($self, $args) = @_;
-    return $self->load_plugins(("Archive::BagIt::Plugin::Manifest::MD5", "Archive::BagIt::Plugin::Manifest::SHA512"));
+    if (!defined $self->use_plugins()) {
+        return $self->load_plugins(("Archive::BagIt::Plugin::Manifest::MD5", "Archive::BagIt::Plugin::Manifest::SHA512"));
+    }
+    return $self->load_plugins($self->use_plugins());
 }
 
 ###############################################
@@ -67,6 +70,12 @@ has 'bag_path' => (
     is => 'rw',
 );
 
+# if the user wants specific plugins!
+has 'use_plugins' => (
+    is   => 'rw',
+    lazy => 1,
+);
+
 ###############################################
 
 has 'bag_path_arr' => (
@@ -511,8 +520,8 @@ sub _build_rel_metadata_path {
 
 sub _build_checksum_algos {
     my($self) = @_;
-    my $checksums = [ 'md5', 'sha1', 'sha256', 'sha512' ];
-    return $checksums;
+    my @checksums = keys %{ $self->manifests() };
+    return \@checksums;
 }
 
 sub _build_manifest_files {
@@ -971,7 +980,7 @@ Archive::BagIt - The main module to handle bags.
 
 =head1 VERSION
 
-version 0.087
+version 0.088
 
 =head1 NAME
 
@@ -1189,6 +1198,8 @@ The arguments are:
 =item C<use_parallel> - if set it uses Parallel::parallel_map to calculate digests of payload files in parallel,
       only useful if underlying filesystem supports parallel read and if multiple CPU cores available.
 
+=item C<use_plugins> - expected manifest plugin strings, if set it uses the requested plugins, example C<Archive::BagIt::Plugin::Manifest::SHA256>
+
 =back
 
 The bag object will use $bag_dir, BUT an existing $bag_dir is not read. If you use C<store()> an existing bag will be overwritten!
